@@ -1,6 +1,6 @@
 /***************************************************************************
-    smb4kauthinfo.h  -  This class provides a container for the 
-    authentication data that is passed and taken by the password reader.
+    smb4kauthinfo.h  -  This class provides a container for the
+    authentication data.
                              -------------------
     begin                : Sa Feb 28 2004
     copyright            : (C) 2004 by Alexander Reinholdt
@@ -8,12 +8,20 @@
  ***************************************************************************/
 
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
+ *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KAUTHINFO_H
@@ -23,12 +31,12 @@
 #include <qstring.h>
 
 /**
- * This class provides a container for the authentication info that
- * is passed and taken by the password reader.
- * @author Alexander Reinholdt
+ * This class provides a container for the authentication data.
+ *
+ * @author Alexander Reinholdt <dustpuppy@users.berlios.de>
  */
 
- 
+
 class Smb4KAuthInfo
 {
   public:
@@ -52,47 +60,62 @@ class Smb4KAuthInfo
     Smb4KAuthInfo() {}
     /**
      * The copy constructor.
+     *
+     * @param info      The Smb4KAuthInfo object that will be copied.
      */
-    Smb4KAuthInfo( const Smb4KAuthInfo &info );
+    Smb4KAuthInfo( Smb4KAuthInfo &info );
     /**
      * The destructor
      */
     ~Smb4KAuthInfo();
     /**
      * Returns the name of the workgroup.
+     *
+     * @returns         The workgroup of the server/share for which this
+     *                  authentication data is for.
      */
-    QString workgroup() const { return m_workgroup; }
+    const QString &workgroup() { return m_workgroup; }
     /**
-     * Returns the name of the workgroup.
+     * Returns the name of the server (host).
+     *
+     * @returns         The server name
      */
-    QString host() const { return m_host; }
+    const QString &host() { return m_host; }
     /**
      * Returns the name of the share.
+     *
+     * @returns         The share name
      */
-    QString share() const { return m_share; }
+    const QString &share() { return m_share; }
     /**
      * Returns the user's name.
+     *
+     * @returns         The user name
      */
-    QString user() const { return m_user; }
+    const QString &user() { return m_user; }
     /**
-     * Returns the password like the user provided it. This might cause 
-     * problems with shell commands, so only use this if you want to 
-     * store the password or for the askpass dialog.
+     * Returns the (unescaped) password.
      */
-    QString password() const { return m_password; }
+    const QString &password() { return m_password; }
     /**
      * Sets the user name.
+     *
+     * @param user      The user name for the server/share
      */
     void setUser( const QString &user );
     /**
      * Sets the password.
+     *
+     * @param passwd    The password for the server/share
      */
     void setPassword( const QString &passwd );
     /**
      * Sets the share name.
+     *
+     * @param share     The name of the share
      */
     void setShare( const QString &share );
-    
+
   private:
     /**
      * The workgroup object.
@@ -114,7 +137,7 @@ class Smb4KAuthInfo
      * The password object for this share.
      */
     QString m_password;
-    
+
 };
 
 #endif
