@@ -35,6 +35,9 @@
 #include <kapplication.h>
 #include <kpassivepopup.h>
 
+// system specific includes
+#include <stdlib.h>
+
 // application specific includes
 #include "smb4kscanner.h"
 #include "smb4kmounter.h"
@@ -213,6 +216,7 @@ void Smb4KCore::searchPrograms()
   fileList << "xargs";
   fileList << "rmdir";
   fileList << "ls";
+  fileList << "sh";
   fileList << "nmblookup";
   fileList << "smbclient";
   fileList << "smbspool";
