@@ -89,6 +89,8 @@ Smb4KFileIO::Smb4KFileIO( QObject *parent, const char *name )
   m_temp_dir = QDir( createtmpdir( tmp_dir ) );
 
   m_state = Idle;
+  
+  m_error_code = None;
 
   connect( m_proc, SIGNAL( receivedStderr( KProcess *, char *, int ) ),
            this,   SLOT( slotReceivedStderr( KProcess *, char *, int ) ) );
@@ -285,7 +287,7 @@ bool Smb4KFileIO::writeSuperUserEntries( const QString &program, bool force, boo
           m_state = readSudoers;
           sudoers_item = item;
 
-          *m_proc << "kdesu -t smb4k_cat " << sudoers_item.path();
+          *m_proc << "kdesu -t smb4k_cat " << sudoers_item.path() << " ; sleep 2";
           m_proc->start( KProcess::NotifyOnExit, KProcess::AllOutput );
         }
         else
@@ -423,7 +425,7 @@ bool Smb4KFileIO::removeSuperUserEntries( const QString &prog )
         m_state = readSudoers;
         sudoers_item = item;
 
-        *m_proc << "kdesu -t smb4k_cat " << sudoers_item.path();
+        *m_proc << "kdesu -t smb4k_cat " << sudoers_item.path() << " ; sleep 2";
         m_proc->start( KProcess::NotifyOnExit, KProcess::AllOutput );
       }
       else
@@ -533,6 +535,7 @@ Smb4KFileIO::FileItem Smb4KFileIO::readConfigFile( const QString &fileName, bool
       if ( file.open( IO_ReadOnly ) )
       {
         QTextStream ts( &file );
+        ts.setEncoding( QTextStream::Locale );
 
         while ( !ts.atEnd() )
         {
@@ -623,6 +626,8 @@ bool Smb4KFileIO::writeFile( Smb4KFileIO::FileItem *item )
     if ( !tmp_file.exists() && tmp_file.open( IO_WriteOnly ) )
     {
       QTextStream ts( &tmp_file );
+      ts.setEncoding( QTextStream::Locale );
+
       ts << contents.join( "\n" ) << endl;
       tmp_file.close();
     }
@@ -681,12 +686,6 @@ bool Smb4KFileIO::writeFile( Smb4KFileIO::FileItem *item )
 
 void Smb4KFileIO::processSudoers()
 {
-  if ( m_buffer.contains( "smb4k_cat" ) != 0 )
-  {
-    showCoreError( ERROR_READING_FILE, sudoers_item.path() );
-    return;
-  }
-
   // Stop here if the user cancelled the kdesu dialog or supplied a
   // wrong password.
   // FIXME: Testing only the buffer may be a potential problem: What
@@ -708,7 +707,7 @@ void Smb4KFileIO::processSudoers()
     m_buffer.truncate( m_buffer.length() - 1 );
   }
 
-  QStringList contents = QStringList::split( "\n", m_buffer, true );
+  QStringList contents = QStringList::split( '\n', m_buffer, true );
 
   bool write = false;
 
@@ -893,6 +892,7 @@ bool Smb4KFileIO::write_lock_file( const QString &filename )
             showCoreError( ERROR_WRITING_FILE, (*it)->absFilePath() );
           }
 
+          emit error_suid_writing();
           emit finished_suid_writing();
           return ok;
         }
@@ -913,6 +913,7 @@ bool Smb4KFileIO::write_lock_file( const QString &filename )
     if ( lock_file.open( IO_WriteOnly ) )
     {
       QTextStream ts( &lock_file );
+      ts.setEncoding( QTextStream::Locale );
 
       ts << getenv( "USER" ) << ":" << filename << endl;
     }
@@ -931,6 +932,8 @@ bool Smb4KFileIO::write_lock_file( const QString &filename )
     if ( lock_file.open( IO_ReadWrite ) )
     {
       QTextStream ts( &lock_file );
+      ts.setEncoding( QTextStream::Locale );
+
       QStringList contents = QStringList::split( '\n', ts.read(), false );
       QString test_string = QString( ":%2" ).arg( filename );
       QString entry = contents.grep( test_string, true ).join( "\n" ).stripWhiteSpace();
@@ -1025,6 +1028,8 @@ bool Smb4KFileIO::remove_lock_file()
     if ( lock_file.open( IO_ReadOnly ) )
     {
       QTextStream ts( &lock_file );
+      ts.setEncoding( QTextStream::Locale );
+
       contents = QStringList::split( '\n', ts.read().stripWhiteSpace(), false );
 
       lock_file.close();
@@ -1050,6 +1055,8 @@ bool Smb4KFileIO::remove_lock_file()
       if ( lock_file.open( IO_WriteOnly ) )
       {
         QTextStream ts( &lock_file );
+        ts.setEncoding( QTextStream::Locale );
+
         ts << contents.join( "\n" ) << endl;
         lock_file.close();
       }
@@ -1070,7 +1077,13 @@ bool Smb4KFileIO::remove_lock_file()
 
 void Smb4KFileIO::slotReceivedStderr( KProcess *, char *buf, int len )
 {
-  m_buffer.append( QString::fromLocal8Bit( buf, len ) );
+  if ( m_buffer.contains( "smb4k_cat" ) != 0 )
+  {
+    m_error_code = Cat;
+    
+    showCoreError( ERROR_READING_FILE, sudoers_item.path() );
+    return;
+  }
 }
 
 
@@ -1092,7 +1105,18 @@ void Smb4KFileIO::slotProcessExited( KProcess * )
     case readSudoers:
       m_state = Idle;
       m_proc->clearArguments();
-      processSudoers();
+      
+      if ( m_error_code == None )
+      {
+        processSudoers();
+      }
+      else
+      {
+        emit error_suid_writing();
+        emit finished_suid_writing();
+        remove_lock_file();
+      }
+      
       m_buffer = QString::null;
       break;
     default:
@@ -1100,6 +1124,8 @@ void Smb4KFileIO::slotProcessExited( KProcess * )
       m_proc->clearArguments();
       break;
   }
+  
+  m_error_code = None;
 }
 
 
