@@ -277,6 +277,16 @@ class Smb4KFileIO : public QObject
      * that were read by smb4k_cat.
      */
     QString m_buffer;
+    
+    /**
+     * Enumeration for errors
+     */
+    enum Error { None, Cat };
+    
+    /**
+     * The error code
+     */
+    int m_error_code;
 };
 
 #endif
