@@ -711,6 +711,19 @@ void Smb4KGlobal::showCoreError( int code, const QString &message )
     case ERROR_OPENING_FILE:
       KMessageBox::error( 0, i18n( "The file %1 could not be opened." ).arg( message ) );
       break;
+    case ERROR_IMPORTING_SHARES:
+    {
+      if ( message.stripWhiteSpace().isEmpty() )
+      {
+        KMessageBox::error( 0, i18n( "The list of mounted SMBFS and CIFS shares could not be imported.\nUnfortunately, there was no error message." ) );
+      }
+      else
+      {
+        KMessageBox::detailedError( 0, i18n( "The list of mounted SMBFS and CIFS shares could not be imported.\nRead the error message under 'Details' to find out more." ), message );
+      }
+
+      break;
+    }
     default:
       break;
   }
