@@ -92,7 +92,7 @@ class Smb4KMounterPrivate
 
           DIR *dir = NULL;
 
-          if ( (dir = opendir( m_mountpoint.ascii() )) != NULL )
+          if ( (dir = opendir( m_mountpoint.local8Bit() )) != NULL )
           {
             m_broken = false;
           }
@@ -292,6 +292,7 @@ void Smb4KMounter::import()
     if ( m_proc_mounts.open( IO_ReadOnly ) )
     {
       QTextStream ts( &m_proc_mounts );
+      ts.setEncoding( QTextStream::Locale );
 
       while( !ts.atEnd() )
       {
@@ -502,7 +503,7 @@ void Smb4KMounter::import()
     {
       struct statvfs fs;
 
-      if ( statvfs( (*it)->path(), &fs ) == -1 )
+      if ( statvfs( (*it)->path().local8Bit(), &fs ) == -1 )
       {
         int err_code = errno;
 
@@ -1140,7 +1141,7 @@ void Smb4KMounter::processMount()
       {
         struct statvfs fs;
 
-        if ( statvfs( share->path(), &fs ) == -1 )
+        if ( statvfs( share->path().local8Bit(), &fs ) == -1 )
         {
           int err_code = errno;
 
@@ -1219,9 +1220,12 @@ void Smb4KMounter::processMount()
 
   if ( m_proc->normalExit() )
   {
-    if ( m_buffer.contains( "Authentication error", true ) == 0
-         && m_buffer.contains( "Connection refused", true ) == 0
-         && m_buffer.contains( "Operation not permitted", true ) == 0 )
+    if ( m_buffer.contains( "syserr =", true ) == 0 &&
+         /* To make sure we catch all errors, also check for the following
+            strings. Maybe we can remove them?? */
+         m_buffer.contains( "Authentication error", true ) == 0 &&
+         m_buffer.contains( "Connection refused", true ) == 0 &&
+         m_buffer.contains( "Operation not permitted", true ) == 0 )
     {
       import();  // FIXME: *cough* What is this for???
 
@@ -1257,7 +1261,7 @@ void Smb4KMounter::processMount()
       {
         struct statvfs fs;
 
-        if ( statvfs( share->path(), &fs ) == -1 )
+        if ( statvfs( share->path().local8Bit(), &fs ) == -1 )
         {
           int err_code = errno;
 
