@@ -97,7 +97,7 @@ void Smb4KPasswordHandler::open_close_wallet()
 
   if ( config()->readBoolEntry( "Use Wallet", true ) )
   {
-    if ( !m_wallet )
+    if ( !m_wallet || (m_wallet && !m_wallet->isOpen()) )
     {
       m_wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous );
 
@@ -757,7 +757,6 @@ void Smb4KPasswordHandler::slotReceivePassword( KProcess *, char *buffer, int bu
 
 void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
 {
-
   delete proc;
 
 #ifdef __FreeBSD__
@@ -776,6 +775,7 @@ void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
     if ( file.open( IO_ReadOnly ) )
     {
       QTextStream ts( &file );
+      ts.setEncoding( QTextStream::Locale );
 
       while ( !ts.atEnd() )
       {
@@ -873,6 +873,7 @@ void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
   if ( file.open( IO_WriteOnly ) )
   {
     QTextStream ts( &file );
+    ts.setEncoding( QTextStream::Locale );
 
     for ( QStringList::ConstIterator it = contents.begin(); it != contents.end(); ++it )
     {
