@@ -127,6 +127,11 @@ bool Smb4KPrint::init( Smb4KPrintInfo *info )
     ok = false;
   }
 
+  if ( !m_info )
+  {
+    delete info;
+  }
+
   return ok;
 }
 
@@ -304,17 +309,15 @@ void Smb4KPrint::endPrintProcess()
     else
     {
       showCoreError( ERROR_PRINTING, m_buffer );
+
+      // Clean up:
+      QFile::remove( "/tmp/smb4k_print_"+QString( "%1" ).arg( getenv( "USER" ) )+".ps" );
     }
   }
   else
   {
-    QStringList list = QStringList::split( '\n', m_buffer, false );
-
-    if ( list.last().startsWith( "putting file" ) )
-    {
-      QFile::remove( "/tmp/smb4k_print_"+QString( "%1" ).arg( getenv( "USER" ) )+".ps" );
-      emit state( PRINT_STOP );
-    }
+    // Clean up:
+    QFile::remove( "/tmp/smb4k_print_"+QString( "%1" ).arg( getenv( "USER" ) )+".ps" );
   }
 }
 
