@@ -351,23 +351,29 @@ void Smb4KScanner::scanForWorkgroupMembers( const QString &workgroup, const QStr
 
   if ( !ip.isEmpty() )
   {
-    command.append( "IPADDR="+KProcess::quote( ip )+" &&" );
+    command.append( "echo \"*** "+master+": "+ip+" ***\" && " );
+    command.append( "net "+netOptions( "server domain" ) );
+    command.append( " -I "+ip );
+    command.append( " -w "+KProcess::quote( workgroup ) );
+    command.append( " -S "+KProcess::quote( master ) );
+    // NOTE: Do not set the environment variables USER and PASSWD
+    // here, because this won't work at all (Why?).
+    command.append( " -U %" );
   }
   else
   {
-    command.append( "IPADDR=`net "+netOptions( "lookup host "+KProcess::quote( master ) )+" -S "+KProcess::quote( master )+" -w "+KProcess::quote( workgroup )+" -U %` &&" );
+    command.append( "net "+netOptions( "lookup host "+KProcess::quote( master ) ) );
+    command.append( " -S "+KProcess::quote( master )+" -w "+KProcess::quote( workgroup )+" -U % " );
+    command.append( "| xargs -IIPADDR sh -c 'echo \"*** "+master+": IPADDR ***\" && ");
+    command.append( "net "+netOptions( "server domain" ) );
+    command.append( " -I IPADDR" );
+    command.append( " -w "+KProcess::quote( workgroup ) );
+    command.append( " -S "+KProcess::quote( master ) );
+    // NOTE: Do not set the environment variables USER and PASSWD
+    // here, because this won't work at all (Why?).
+    command.append( " -U %'" );
   }
 
-  command.append( " echo \"*** "+master+": $IPADDR ***\" &&" );
-  command.append( " net "+netOptions( "server domain" ) );
-  command.append( " -w "+KProcess::quote( workgroup ) );
-  command.append( " -S "+KProcess::quote( master ) );
-  command.append( " -I $IPADDR" );
-
-  // NOTE: Do not set the environment variables USER and PASSWD
-  // here, because this won't work at all (Why?).
-  command.append( " -U %" );
-
   *m_main_proc << command;
 
   startMainProcess( Hosts );
@@ -453,7 +459,6 @@ void Smb4KScanner::scanForInfo( const QString &workgroup, const QString &host, c
 /****************************************************************************
    Searches for a host. (private part)
 ****************************************************************************/
-#include <kmessagebox.h>
 
 void Smb4KScanner::searchForHost( const QString &host )
 {
@@ -869,7 +874,8 @@ void Smb4KScanner::processHosts()
 
   if ( (m_main_buffer.contains( "Could not connect to server", true ) != 0 &&
         m_main_buffer.contains( "The username or password was not correct.", true ) == 0) ||
-       m_main_buffer.contains( "Unable to find a suitable server" ) != 0 )
+       m_main_buffer.contains( "Unable to find a suitable server" ) != 0 ||
+       m_main_buffer.contains( "Invalid ip address specified" ) != 0 )
   {
     // We remove the first line, because the IP address of the master
     // is reported there.
@@ -1000,6 +1006,8 @@ void Smb4KScanner::processShares()
   // Error handling
   if ( m_main_buffer.contains( "The username or password was not correct.", true ) != 0 )
   {
+    emit authFailed();
+
     if ( m_password_handler->askpass( sp.mainData->workgroup(), sp.mainData->host(), QString::null, Smb4KPasswordHandler::AccessDenied ) )
     {
       m_queue.enqueue( new QString( QString( "%1:%2:%3:%4:%5" ).arg( Shares ).arg( sp.mainData->workgroup(), sp.mainData->host(), sp.mainData->ip(), QString::null ) ) );
@@ -1107,6 +1115,8 @@ void Smb4KScanner::processPreview()
       if ( QString::compare( errmsg, "NT_STATUS_ACCESS_DENIED" ) == 0 ||
            QString::compare( errmsg, "NT_STATUS_LOGON_FAILURE" ) == 0 )
       {
+        emit authFailed();
+
         int state = Smb4KPasswordHandler::None;
 
         if ( QString::compare( errmsg, "NT_STATUS_ACCESS_DENIED" ) == 0 )
@@ -1220,7 +1230,9 @@ void Smb4KScanner::processSearch()
       emit searchResult( new Smb4KHostItem( workgroup, host, QString::null, ip ) );
     }
     else
+    {
       emit searchResult( new Smb4KHostItem() );
+    }
   }
   else
   {
@@ -1409,6 +1421,19 @@ void Smb4KScanner::connect_timer( bool con )
 }
 
 
+/****************************************************************************
+   Add a host to the host list
+****************************************************************************/
+
+void Smb4KScanner::addHost( Smb4KHostItem *host )
+{
+  if ( host )
+  {
+    m_hosts_list.append( host );
+  }
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 // SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
