@@ -179,6 +179,13 @@ class Smb4KScanner : public QObject
      */
     Smb4KHostItem *getHost( const QString &name, const QString &workgroup = QString::null );
 
+    /**
+     * This function appends a host to the list of known servers.
+     *
+     * @param host          The host to add
+     */
+    void addHost( Smb4KHostItem *host );
+
   signals:
     /**
      * This signal emits the run state.
@@ -237,6 +244,11 @@ class Smb4KScanner : public QObject
      */
     void hostListChanged();
 
+    /**
+     * This signal is emitted if the authentication failed.
+     */
+    void authFailed();
+
   protected:
     /**
      * Starts the main process.
