@@ -428,13 +428,20 @@ void Smb4KSynchronizer::slotReceivedStdout( KProcess *, char *buf, int len )
 
 void Smb4KSynchronizer::slotReceivedStderr( KProcess *, char *buf, int len )
 {
+  QString error_message = QString::fromLocal8Bit( buf, len );
+
   // At least under Debian unstable (20051216), rsync emits an error
   // when you kill the process (using SIGTERM). Pressing the cancel
   // button will exactly do this. Thus, we need to exclude this occasion
   // from here.
-  if ( !cancel )
+  if ( !cancel && error_message.contains( "rsync error:", true ) != 0 )
   {
-    showCoreError( ERROR_SYNCHRONIZING, QString::fromLocal8Bit( buf, len ) );
+    // Cancel the whole synchronization in case an error occurred.
+    // If we don't do it, the user might be flooded with error messages
+    // especially if you try to synchronize a local copy with a remote
+    // share that is mounted read-only.
+    abort();
+    showCoreError( ERROR_SYNCHRONIZING, error_message );
   }
   else
   {
