@@ -7,12 +7,20 @@
  ***************************************************************************/
 
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
+ *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KAPPEARANCEOPTIONS_H
@@ -27,12 +35,17 @@
 #include <qradiobutton.h>
 #include <qcheckbox.h>
 
+/** The configuration dialog for the appearance of Smb4K.
+ *
+ * @author Alexander Reinholdt  <dustpuppy@mail.berlios.de>
+ */
+
 class Smb4KAppearanceOptions : public QWidget
 {
   Q_OBJECT
-  
+
   friend class Smb4KOptionsDlg;
-  
+
   public:
     /**
      * The constructor
@@ -43,6 +56,14 @@ class Smb4KAppearanceOptions : public QWidget
      */
     ~Smb4KAppearanceOptions();
 
+  protected slots:
+    /**
+     * Enables/disables buttons according to the toggle state of the "Show hidden shares." button.
+     *
+     * @param state  Describes the toggle state of the "Show hidden shares"  checkbox.
+     */
+    void slotShowHiddenShares( int state );
+
   private:
     /**
      * The checkbox for the appearance of the share view.
@@ -85,6 +106,16 @@ class Smb4KAppearanceOptions : public QWidget
      * Show the IP address of the host.
      */
     QCheckBox *m_showIP;
-  
+    /**
+     * This check box determines whether the tool tip with the
+     * info of the share should be shown.
+     */
+    QCheckBox *m_showShareTooltip;
+    /**
+     * This check box determies whether the tool tip with the
+     * info about a network item should be shown.
+     */
+    QCheckBox *m_showNetworkItemTooltip;
+
 };
 #endif
