@@ -7,12 +7,20 @@
  ***************************************************************************/
 
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
+ *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
 // Qt includes
@@ -26,6 +34,7 @@
 #include <kaccel.h>
 #include <kiconloader.h>
 #include <kconfig.h>
+#include <kmessagebox.h>
 
 // application specific includes
 #include "smb4kbookmarkeditor.h"
@@ -33,7 +42,7 @@
 #include "../core/smb4kcore.h"
 #include "../core/smb4kglobal.h"
 
-using namespace Smb4K_Global;
+using namespace Smb4KGlobal;
 
 
 Smb4KBookmarkEditor::Smb4KBookmarkEditor( QWidget *parent, const char *name )
@@ -46,8 +55,15 @@ Smb4KBookmarkEditor::Smb4KBookmarkEditor( QWidget *parent, const char *name )
   layout->setSpacing( 5 );
 
   m_view = new KListView( frame );
-  m_view->addColumn( i18n( "Bookmarks" ), -1 );
+  m_view->addColumn( i18n( "Bookmark" ), -1 );
+  m_view->addColumn( i18n( "Workgroup/Domain" ), -1 );
+  m_view->addColumn( i18n( "IP Address" ), -1 );
   m_view->setResizeMode( QListView::LastColumn );
+  m_view->setAllColumnsShowFocus( true );
+  m_view->setItemsRenameable( true );
+  m_view->setRenameable( 0, false );
+  m_view->setRenameable( 1, true );
+  m_view->setRenameable( 2, true );
 
   m_collection = new KActionCollection( this, "BookmarkEditor_ActionCollection", KGlobal::instance() );
 
@@ -60,13 +76,13 @@ Smb4KBookmarkEditor::Smb4KBookmarkEditor( QWidget *parent, const char *name )
 
   for ( QValueList<Smb4KBookmark *>::ConstIterator it = bookmarks.begin(); it != bookmarks.end(); ++it )
   {
-    QListViewItem *item = new QListViewItem( m_view, (*it)->getShare() );
+    QListViewItem *item = new QListViewItem( m_view, (*it)->bookmark(), (*it)->workgroup(), (*it)->ip() );
     item->setPixmap( 0, SmallIcon( "folder" ) );
   }
 
   layout->addWidget( m_view, 0, 0, 0 );
 
-  config()->setGroup( "General Options" );
+  config()->setGroup( "Dialogs" );
   setInitialSize( config()->readSizeEntry( "Bookmark Editor Geometry", 0L ) );
 
   connect( m_view, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ), this, SLOT( slotRightButtonPressed( QListViewItem *, const QPoint &, int ) ) );
@@ -78,6 +94,14 @@ Smb4KBookmarkEditor::Smb4KBookmarkEditor( QWidget *parent, const char *name )
 
 Smb4KBookmarkEditor::~Smb4KBookmarkEditor()
 {
+  uint index = 0;
+
+  while ( index < m_collection->count() )
+  {
+    delete m_collection->action( index++ );
+  }
+
+  m_collection->clear();
 }
 
 
@@ -146,14 +170,19 @@ void Smb4KBookmarkEditor::slotOkClicked()
 
     while( it.current() )
     {
-      bookmarks.append( new Smb4KBookmark( it.current()->text( 0 ), QString::null ) );
+      bookmarks.append( new Smb4KBookmark(
+                         it.current()->text( 0 ).section( "/", 2, 2 ).stripWhiteSpace(),
+                         it.current()->text( 0 ).section( "/", 3, 3 ).stripWhiteSpace(),
+                         it.current()->text( 1 ).stripWhiteSpace(),
+                         it.current()->text( 2 ).stripWhiteSpace(),
+                         "Disk" ) );
       ++it;
     }
   }
 
   smb4k_core->bookmarkHandler()->writeBookmarkList( bookmarks );
 
-  config()->setGroup( "General Options" );
+  config()->setGroup( "Dialogs" );
   config()->writeEntry( "Bookmark Editor Geometry", size() );
   config()->sync();
 }
@@ -169,7 +198,7 @@ void Smb4KBookmarkEditor::slotCancelClicked()
     m_collection->remove( *it );
   }
 
-  config()->setGroup( "General Options" );
+  config()->setGroup( "Dialogs" );
   config()->writeEntry( "Bookmark Editor Geometry", size() );
   config()->sync();
 }
