@@ -220,6 +220,15 @@ void Smb4KBrowserWidget::setOpen( QListViewItem *item, bool open )
 
 void Smb4KBrowserWidget::insertItem( Smb4KHostItem *item )
 {
+  if ( item )
+  {
+    smb4k_core->scanner()->addHost( item );
+  }
+  else
+  {
+    return;
+  }
+
   if ( smb4k_core->scanner()->getWorkgroup( item->workgroup() ) == 0 )
   {
     smb4k_core->scanner()->appendWorkgroup( new Smb4KWorkgroupItem( item->workgroup(), item->name(), item->ip() ) );
@@ -239,7 +248,9 @@ void Smb4KBrowserWidget::insertItem( Smb4KHostItem *item )
 
       emit itemInserted( item );
     }
-    else if ( hostItem && QString::compare( hostItem->parent()->text( Network ), item->workgroup() ) != 0 )
+    else if ( hostItem && hostItem->parent() /* Strange: Under some circumstances it might occurr
+              that a workgroup is recognized as a server. (reported by Giuseppe Della Bianca) */ &&
+              QString::compare( hostItem->parent()->text( Network ), item->workgroup() ) != 0 )
     {
       Smb4KBrowserWidgetItem *newItem = new Smb4KBrowserWidgetItem( workgroupItem, item );
       newItem->setExpandable( true );
@@ -627,6 +638,11 @@ void Smb4KBrowserWidget::slotShares( const QValueList<Smb4KShareItem *> &list )
 
       if ( host != 0 )
       {
+        if ( !host->isOpen() )
+        {
+          setOpen( host, true );
+        }
+
         if ( !m_hidden && (*it)->name().stripWhiteSpace().endsWith( "$" ) )
         {
           continue;
@@ -933,4 +949,13 @@ void Smb4KBrowserWidget::slotAddInfo( Smb4KHostItem *item )
   }
 }
 
+
+void Smb4KBrowserWidget::slotAuthFailed()
+{
+  if ( currentItem() && currentItem()->isOpen() )
+  {
+    setOpen( currentItem(), false );
+  }
+}
+
 #include "smb4kbrowserwidget.moc"
