@@ -251,6 +251,12 @@ class Smb4KBrowserWidget : public KListView
      */
     void slotAddInfo( Smb4KHostItem *item );
 
+    /**
+     * This slot is invoked, if the authentication failed. It collapses the
+     * subtree of the current item.
+     */
+    void slotAuthFailed();
+
   private:
     /**
      * This value is TRUE, if the hidden shares are to be shown, otherwise
