@@ -487,14 +487,21 @@ bool Smb4KOptionsDlg::saveOptions()
   QString fmask = m_sambaPage->m_fmask->text().stripWhiteSpace();
   QString dmask = m_sambaPage->m_dmask->text().stripWhiteSpace();
 
-  if ( !fmask.startsWith( "0" ) )
+  // We need to make sure that the masks have 4 digits:
+  if ( fmask.length() < 4 )
   {
-    fmask.prepend( "0" );
+    while ( fmask.length() < 4 )
+    {
+      fmask.prepend( "0" );
+    }
   }
 
-  if ( !dmask.startsWith( "0" ) )
+  if ( dmask.length() < 4 )
   {
-    dmask.prepend( "0" );
+    while ( dmask.length() < 4 )
+    {
+      dmask.prepend( "0" );
+    }
   }
 
   config()->writeEntry( "Mount FMASK", fmask );
@@ -912,6 +919,9 @@ void Smb4KOptionsDlg::readOptions()
   m_sambaPage->m_gid->insertStringList( gid, -1 );
   m_sambaPage->m_gid->setCurrentText( config()->readEntry( "Mount GID", i18n( "default" ) ) );
 
+#ifdef __linux__
+  // Under Linux the codepage and charset are only supported for
+  // Kernels >= 2.4.0.
   if ( k_major >= 2 && k_minor >= 4 && k_rev >= 0 )
   {
     m_sambaPage->m_codepage->setCurrentText( config()->readEntry( "Mount Codepage", i18n( "default" ) ) );
@@ -919,21 +929,35 @@ void Smb4KOptionsDlg::readOptions()
   }
   else
   {
-    m_sambaPage->m_codepage->setEnabled( false );
-    m_sambaPage->m_charset->setEnabled( false );
+    ((QWidget *)m_sambaPage->child( "SambaCharsetCodepage", "QGroupBox", true ))->setEnabled( false );
   }
+#else
+  // Other operating systems than Linux also support the codepage
+  // and charset options. Up to now, now restrictions like under
+  // Linux are known. Include them here if some emerge:
+  m_sambaPage->m_codepage->setCurrentText( config()->readEntry( "Mount Codepage", i18n( "default" ) ) );
+  m_sambaPage->m_charset->setCurrentText( config()->readEntry( "Mount Charset", i18n( "default" ) ) );
+#endif
 
-  QString fmask = config()->readEntry( "Mount FMASK", QString( "%1" ).arg( 0777 - mask, 0, 8 ) );
+  QString fmask = config()->readEntry( "Mount FMASK", QString( "%1" ).arg( 0777
+- mask, 0, 8 ) );
   QString dmask = config()->readEntry( "Mount DMASK", QString( "%1" ).arg( 0777 - mask, 0, 8 ) );
 
-  if ( !fmask.startsWith( "0" ) )
+  // We need to make sure that the masks have 4 digits:
+  if ( fmask.length() < 4 )
   {
-    fmask.prepend( "0" );
+    while ( fmask.length() < 4 )
+    {
+      fmask.prepend( "0" );
+    }
   }
 
-  if ( !dmask.startsWith( "0" ) )
+  if ( dmask.length() < 4 )
   {
-    dmask.prepend( "0" );
+    while ( dmask.length() < 4 )
+    {
+      dmask.prepend( "0" );
+    }
   }
 
   m_sambaPage->m_fmask->setText( fmask );
