@@ -7,12 +7,20 @@
  ***************************************************************************/
 
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
+ *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KPREVIEWDIALOG_H
@@ -27,7 +35,6 @@
 
 // KDE includes
 #include <kdialogbase.h>
-#include <kconfig.h>
 #include <kiconview.h>
 #include <ktoolbar.h>
 #include <kcombobox.h>
@@ -46,9 +53,28 @@ class Smb4KPreviewDialog : public KDialogBase
   friend class Smb4KApp;
 
   public:
-    /** The constructor. */
+    /**
+     * This is the constructor of the preview dialog.
+     *
+     * @param workgroup     The workgroup the share is in that is to be previewed
+     *
+     * @param host          The host where the share is located
+     *
+     * @param ip            The IP address of the host
+     *
+     * @param share         The share name. Please note, that the preview dialog won't
+     *                      be shown, if the share name is empty.
+     *
+     * @param parent        The parent of this widget
+     *
+     * @param name          The name of this widget
+     *
+     * @param modal         Sets the modal mode for this widget
+     */
     Smb4KPreviewDialog( const QString &workgroup, const QString &host, const QString &ip, const QString &share, QWidget *parent = 0, const char *name = 0, bool modal = false );
-    /** The destructor. */
+    /**
+     * The destructor.
+     */
     ~Smb4KPreviewDialog();
 
   protected slots:
