@@ -7,12 +7,20 @@
  ***************************************************************************/
 
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   General Public License for more details.                              *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
+ *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
 #ifndef SMB4KSHAREOPTIONS_H
@@ -26,31 +34,42 @@
 #include <qwidget.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
+#include <qlabel.h>
 
 // KDE includes
 #include <kurlrequester.h>
+#include <knuminput.h>
 
 class Smb4KShareOptions : public QWidget
 {
   friend class Smb4KOptionsDlg;
-  
+
   Q_OBJECT
   public:
-    /** 
-     * The constructor. 
+    /**
+     * The constructor.
      */
     Smb4KShareOptions( QWidget *parent = 0, const char *name = 0 );
-    /** 
-     * The destructor. 
+    /**
+     * The destructor.
      */
     ~Smb4KShareOptions();
 
   private:
-    KURLRequester *m_defaultPath;
+    /**
+     * This KURLRequester holds the mount prefix.
+     */
+    KURLRequester *m_mount_prefix;
     QCheckBox *m_lowercase;
     QCheckBox *m_unmountAll;
     QCheckBox *m_mountRecent;
     QCheckBox *m_allowUnmountForeign;
     KPushButton *m_removeSUEntries;
+
+    /**
+     * This integer input is to determine the time interval
+     * between checks (broken shares, external (un)mounts).
+     */
+    KIntNumInput *m_check_interval;
 };
 #endif
