@@ -34,6 +34,7 @@
 #include <cerrno>
 using namespace std;
 
+#define SMB4K_CAT_VERSION 0.2
 
 //
 // Usage
@@ -41,14 +42,14 @@ using namespace std;
 
 void info()
 {
-  cout << "This is smb4k_cat, Smb4K's replacement of the 'cat' utility." << endl;
-  cout << "smb4k_cat is used to read system configuration files." << endl;
-  cout << "(c) 2005, Alexander Reinholdt" << endl << endl;
+  cout << "This is smb4k_cat (version " << SMB4K_CAT_VERSION << "), the cat utility of Smb4K" << endl;
+  cout << "Copyright (C) 2005-2006, Alexander Reinholdt" << endl << endl;
   cout << "Usage:" << endl;
-  cout << " smb4k_cat <filename>" << endl;
+  cout << " smb4k_cat {filename}" << endl;
   cout << " smb4k_cat --help" << endl << endl;
   cout << "Arguments:" << endl;
-  cout << "  <filename>\tThe name or the path of the file that is to be opened." << endl;
+  cout << "  {filename}\tThe name or the path of the file that is to be opened." << endl;
+  cout << endl;
   cout << "  --help\tDisplays this help screen and exits." << endl;
   cout << endl;
 }
@@ -59,7 +60,7 @@ void info()
 
 const char *findfile( const char *name )
 {
-  const char *paths[] = { "/etc/", "/usr/local/etc", "/opt/etc/" };
+  const char *paths[] = { "./", "/etc/", "/usr/local/etc", "/opt/etc/" };
   string file = "";
 
   for ( uint i = 0; i < sizeof( paths ) / sizeof( char * ); i++ )
