@@ -34,6 +34,8 @@
 #include <unistd.h>
 using namespace std;
 
+#define SMB4K_KILL_VERSION 0.3
+
 
 //
 // Returns the information about the program
@@ -41,14 +43,18 @@ using namespace std;
 
 void info()
 {
-  cout << "This is smb4k_kill, the kill utility for Smb4K." << endl;
-  cout << "(c) 2004-2005, Alexander Reinholdt" << endl << endl;
+  cout << "This is smb4k_kill (version "<< SMB4K_KILL_VERSION <<"), the kill utility of Smb4K" << endl;
+  cout << "Copyright (C) 2004-2005, Alexander Reinholdt" << endl << endl;
   cout << "Usage:" << endl;
-  cout << " smb4k_kill <options>" << endl;
+  cout << " smb4k_kill -{signum} {pid}" << endl;
   cout << " smb4k_kill --help" << endl << endl;
   cout << "Arguments:" << endl;
+  cout << "  {signum}\tThis is the signal number (see the kill(1) manual page for" << endl;
+  cout << "\t\tmore information)." << endl;
+  cout << endl;
+  cout << "  {pid}\t\tThe ID of the process you want to kill." << endl;
+  cout << endl;
   cout << "  --help\tDisplays this help screen and exits." << endl;
-  cout << "  <options>\tThese are the options that you have to pass to kill." << endl;
   cout << endl;
 }
 
