@@ -34,6 +34,7 @@
 #include <unistd.h>
 using namespace std;
 
+#define SMB4K_MOUNT_VERSION 0.5
 
 //
 // Returns the information about the program
@@ -41,19 +42,27 @@ using namespace std;
 
 void info()
 {
-  cout << "This is smb4k_mount, the mount utility for Smb4K." << endl;
-  cout << "(c) 2004-2006, Alexander Reinholdt" << endl << endl;
+  cout << "This is smb4k_mount (version " << SMB4K_MOUNT_VERSION << "), the mount utility of Smb4K" << endl;
+  cout << "Copyright (C) 2004-2006, Alexander Reinholdt" << endl << endl;
   cout << "Usage:" << endl;
-  cout << " smb4k_mount [--no-suid|--suid] <options>" << endl;
+  cout << " smb4k_mount {startopt} {mntopts} {share} {mountpoint}" << endl;
   cout << " smb4k_mount --help" << endl << endl;
   cout << "Arguments:" << endl;
-  cout << "  --no-suid\tsmb4k_mount invokes smbmount." << endl;
-  cout << "  --suid\tsmb4k_mount invokes mount." << endl;
-  cout << "  --help\tDisplays this help screen and exits." << endl;
-  cout << "  <options>\tThese are the options that you have to pass to the mount" << endl;
+  cout << "  {startopt}" << endl;
+  cout << "    --no-suid\tinvokes smbmount or mount.cifs" << endl;
+  cout << "    --suid\tinvokes mount" << endl;
+  cout << endl;
+  cout << "  {mntopts}\tThese are the options that you have to pass to the mount" << endl;
   cout << "\t\tbinary. Note, that under Linux you must specify the \'-t\'" << endl;
   cout << "\t\toption under any circumstances. Under FreeBSD, however, it" << endl;
-  cout << "\t\tis not recognized and might cause problems." << endl;
+  cout << "\t\tis not recognized and might cause problems. Read the mount(8)" << endl;
+  cout << "\t\tmanual page for a complete overview of the available options." << endl;
+  cout << endl;
+  cout << "  {share}\tThe SMBFS or CIFS share that is to be mounted." << endl;
+  cout << endl;
+  cout << "  {mountpoint}\tThe path where the share should be mounted to." << endl;
+  cout << endl;
+  cout << "  --help\tDisplays this help screen and exits." << endl;
   cout << endl;
 }
 
